@@ -69,6 +69,11 @@ typedef enum {
     CL_EBYTECODE,/* may be reported in testmode */
     CL_EBYTECODE_TESTFAIL, /* may be reported in testmode */
 
+    /* c4w error codes */
+    CL_ELOCK,
+    CL_EBUSY,
+    CL_ESTATE,
+
     /* no error codes below this line please */
     CL_ELAST_ERROR
 } cl_error_t;
@@ -87,6 +92,7 @@ typedef enum {
 #define CL_DB_OFFICIAL_ONLY 0x1000
 #define CL_DB_BYTECODE      0x2000
 #define CL_DB_SIGNED	    0x4000  /* internal */
+#define CL_DB_BYTECODE_UNSIGNED	0x8000
 
 /* recommended db settings */
 #define CL_DB_STDOPT	    (CL_DB_PHISHING | CL_DB_PHISHING_URLS | CL_DB_BYTECODE)
@@ -154,7 +160,7 @@ enum cl_engine_field {
 };
 
 enum bytecode_security {
-    CL_BYTECODE_TRUST_ALL=0, /* insecure, debug setting */
+    CL_BYTECODE_TRUST_ALL=0, /* obsolete */
     CL_BYTECODE_TRUST_SIGNED, /* default */
     CL_BYTECODE_TRUST_NOTHING /* paranoid setting */
 };
